@@ -64,8 +64,11 @@ class ControlPanel(SimpleItem):
         servers = getConfiguration().servers
         servers.sort(lambda x,y: cmp(x.port, y.port))
         for server in servers:
-            if isinstance(server.handlers[0], zhttp_handler):
-                candidates.append(server)
+            try:            
+                if isinstance(server.handlers[0], zhttp_handler):
+                    candidates.append(server)
+            except:
+                pass
 
         candidate = candidates[0]
         ip_address = candidate.server_port 
